==> plastimatch_1.8.0+dfsg.1.orig.tar.xz: plastimatch-1.8.0/src/plastimatch/util/diff.cxx <==
/* -----------------------------------------------------------------------
   See COPYRIGHT.TXT and LICENSE.TXT for copyright and license information
   ----------------------------------------------------------------------- */
#include "plmutil_config.h"
#include <time.h>
#include "itkSubtractImageFilter.h"
#include "itkImageRegionIterator.h"

#include "diff.h"
#include "itk_image_save.h"
#include "plm_image.h"
#include "print_and_exit.h"

Diff_parms::Diff_parms ()
{
}

void
diff_main (Diff_parms* parms)
{
    Plm_image::Pointer img1, img2;

    img1 = plm_image_load_native (parms->img_in_1_fn);
    if (!img1) {
	print_and_exit ("Error: could not open '%s' for read\n",
	    parms->img_in_1_fn.c_str());
    }
    img2 = plm_image_load_native (parms->img_in_2_fn);
    if (!img2) {
	print_and_exit ("Error: could not open '%s' for read\n",
	    parms->img_in_2_fn.c_str());
    }

    if (!Plm_image::compare_headers (img1, img2)) {
	print_and_exit ("Error: image sizes do not match\n");
    }

    FloatImageType::Pointer fi1 = img1->itk_float ();
    FloatImageType::Pointer fi2 = img2->itk_float ();

    typedef itk::SubtractImageFilter< FloatImageType, FloatImageType, 
				      FloatImageType > SubtractFilterType;
    SubtractFilterType::Pointer sub_filter = SubtractFilterType::New();

    sub_filter->SetInput1 (fi1);
    sub_filter->SetInput2 (fi2);

    try {
	sub_filter->Update();
    } catch (itk::ExceptionObject & excep) {
	std::cerr << "ITK exception caught: " << excep << std::endl;
	exit (-1);
    }
    FloatImageType::Pointer diff = sub_filter->GetOutput ();

    itk_image_save_float (diff, parms->img_out_fn.c_str());
}

==> plastimatch_1.9.4+dfsg.1.orig.tar.xz: plastimatch-1.9.4/src/plastimatch/util/diff.cxx <==
/* -----------------------------------------------------------------------
   See COPYRIGHT.TXT and LICENSE.TXT for copyright and license information
   ----------------------------------------------------------------------- */
#include "plmutil_config.h"
#include <time.h>
#include "itkSubtractImageFilter.h"
#include "itkImageRegionIterator.h"

#include "diff.h"
#include "itk_image_save.h"
#include "plm_image.h"
#include "print_and_exit.h"

DeformationFieldType::Pointer
diff_vf (
    const DeformationFieldType::Pointer& vf1,
    const DeformationFieldType::Pointer& vf2
) {
    
    typedef itk::SubtractImageFilter< DeformationFieldType, DeformationFieldType, 
				      DeformationFieldType > SubtractFilterType;
    SubtractFilterType::Pointer sub_filter = SubtractFilterType::New();

    sub_filter->SetInput1 (vf1);
    sub_filter->SetInput2 (vf2);

    try {
	sub_filter->Update();
    } catch (itk::ExceptionObject & excep) {
	std::cerr << "ITK exception caught: " << excep << std::endl;
	exit (-1);
    }
    DeformationFieldType::Pointer vf_diff = sub_filter->GetOutput ();
    return vf_diff;
}

Plm_image::Pointer
diff_image (
    const Plm_image::Pointer& pi1,
    const Plm_image::Pointer& pi2
) {
    
    FloatImageType::Pointer fi1 = pi1->itk_float ();
    FloatImageType::Pointer fi2 = pi2->itk_float ();

    typedef itk::SubtractImageFilter< FloatImageType, FloatImageType, 
				      FloatImageType > SubtractFilterType;
    SubtractFilterType::Pointer sub_filter = SubtractFilterType::New();

    sub_filter->SetInput1 (fi1);
    sub_filter->SetInput2 (fi2);

    try {
	sub_filter->Update();
    } catch (itk::ExceptionObject & excep) {
	std::cerr << "ITK exception caught: " << excep << std::endl;
	exit (-1);
    }
    FloatImageType::Pointer diff = sub_filter->GetOutput ();
    Plm_image::Pointer pi_diff = Plm_image::New (diff);
    return pi_diff;
}
